@@ -20,7 +20,7 @@
 #include "abort.h"
 #include "command.h"
 #include "edit.h"
-#include "fileop.h"
+#include "file.h"
 #include "find.h"
 #include "general.h"
 #include "jump.h"
@@ -108,9 +108,8 @@ void command_saveas(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	gchar *text,*label;
-	GList *glist;
 	TEXTWND *ptw;
-	GtkWidget *dialog,*sub_menu,*menu_item,*child;
+	GtkWidget *dialog,*child;
 
 	child=gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 						gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)));
@@ -143,16 +142,8 @@ void command_saveas(gpointer callback_data,guint callback_action,
 																child,label);
 			g_free(label);
 			/* ɥ˥塼 */
-			menu_item=gtk_menu_item_new_with_label(command_open_file);
-			sub_menu=gtk_item_factory_get_widget(item_factory_menu,
-													_("<main>/ɥ(W)"));
-			glist=gtk_container_children(GTK_CONTAINER(sub_menu));
-			gtk_menu_insert(GTK_MENU(sub_menu),menu_item,
-										g_list_index(glist,ptw->menu_item));
-			g_list_free(glist);
-			gtk_container_remove(GTK_CONTAINER(sub_menu),ptw->menu_item);
-			ptw->menu_item=menu_item;
-			gtk_widget_show(ptw->menu_item);
+			gtk_label_set_text(GTK_LABEL(GTK_BIN(ptw->menu_item)->child),
+															command_open_file);
 			/*  */
 			ptw->create=ptw->edit=FALSE;
 			g_free(ptw->file);
@@ -219,16 +210,15 @@ void command_reload(gpointer callback_data,guint callback_action,
 void command_property(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
-	gboolean modify;
-	gint i,fontsize,lbearing,rbearing,width,ascent,descent;
-	gint max,sx,sy;
+	gint i;
 	FTYPE ft;
-	GdkRectangle rc;
+	GList *glist;
 	TEXTWND *ptw;
 
 	ptw=gtk_object_get_user_data(GTK_OBJECT(
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	ft.ft_id=ptw->ft_id;
 	ft.margin=ptw->margin;
 	ft.tab=ptw->tab;
 	ft.code=ptw->code;
@@ -245,76 +235,42 @@ void command_property(gpointer callback_data,guint callback_action,
 	memcpy(ft.color,ptw->color,sizeof(GdkColor)*12);
 	ft.text=ft.ext=NULL;
 	if (property_dialog(&ft)) {
-		if (ptw->limit!=ft.limit || ptw->tab!=ft.tab
-									|| (ptw->code && ptw->margin!=ft.margin)) {
-			/* ޤ֤ѹֿѹ */
-			delete_list(&ptw->undo);
-			delete_list(&ptw->redo);
+		if (ft.ft_id<0) {
+			/* ̵°ΤȤˤϤΥɥѹ */
+			change_property(ptw,&ft);
+		} else {
+			/* Ʊե륿פ򤹤٤ѹ */
+			ptw->ft_id=ft.ft_id;
+			for (i=0;i<ftnum;i++)
+				if (ftype[i].ft_id==ft.ft_id) {
+					ftype[i].margin=ft.margin;
+					ftype[i].tab=ft.tab;
+					ftype[i].code=ft.code;
+					ftype[i].crlf=ft.crlf;
+					ftype[i].eof=ft.eof;
+					ftype[i].limit=ft.limit;
+					ftype[i].overwrite=ft.overwrite;
+					ftype[i].space=ft.space;
+					ftype[i].gline=ft.gline;
+					ftype[i].mline=ft.mline;
+					ftype[i].uline=ft.uline;
+					ftype[i].vline=ft.vline;
+					g_free(ftype[i].fontname);
+					ftype[i].fontname=g_strdup(ft.fontname);
+					memcpy(ftype[i].color,ft.color,sizeof(GdkColor)*12);
+					break;
+				}
+			glist=gtk_container_children(GTK_CONTAINER(notebook));
+			for (i=g_list_length(glist)-1;i>=0;i--) {
+				ptw=gtk_object_get_user_data(
+										GTK_OBJECT(g_list_nth_data(glist,i)));
+				if (ptw->ft_id==ft.ft_id)
+					change_property(ptw,&ft);
+			}
+			g_list_free(glist);
 		}
-		modify=ptw->limit!=ft.limit || (ptw->limit
-							&& (ptw->tab!=ft.tab || ptw->margin!=ft.margin));
-		ptw->margin=ft.margin;
-		ptw->tab=ft.tab;
-		ptw->code=ft.code;
-		ptw->crlf=ft.crlf;
-		ptw->eof=ft.eof;
-		ptw->limit=ft.limit;
-		ptw->overwrite=ft.overwrite;
-		ptw->space=ft.space;
-		ptw->gline=ft.gline;
-		ptw->mline=ft.mline;
-		ptw->uline=ft.uline;
-		ptw->vline=ft.vline;
-		g_free(ptw->fontname);
-		ptw->fontname=ft.fontname;
-		memcpy(ptw->color,ft.color,sizeof(GdkColor)*12);
-		ptw->select.x=-1;
-		if (modify) {
-			/* ޤ֤ѹޤ֤ͭǥֿѹ */
-			ptw->cursor.x=ptw->cursor.y=ptw->top.x=ptw->top.y=0;
-			modify_margin(ptw);
-		}
-		/* ե */
-		gdk_font_unref(ptw->font);
-		ptw->font=gdk_fontset_load(ptw->fontname);
-		ptw->fontascent=ptw->fontsize=0;
-		for (i=0x20;i<=0x7e;i++) {
-			gdk_text_extents(ptw->font,(gchar *)&i,1,
-								&lbearing,&rbearing,&width,&ascent,&descent);
-			if (ptw->fontascent<ascent)
-				ptw->fontascent=ascent;
-			fontsize=(gdk_char_height(ptw->font,i)+1)/2;
-			if (ptw->fontsize<fontsize)
-				ptw->fontsize=fontsize;
-		}
-		/* С */
-		sx=MAX(ptw->drawing->allocation.width/ptw->fontsize,1);
-		sy=MAX(ptw->drawing->allocation.height/(ptw->fontsize*2),1);
-		if (ptw->top.y>ptw->max-sy)
-			ptw->top.y=MAX(ptw->max-sy,0);
-		max=get_width_max(ptw);
-		if (ptw->top.x>max-sx+1)
-			ptw->top.x=MAX(max-sx+1,0);
-#ifdef USE_XIM
-		if (gdk_im_ready() && ptw->ic!=NULL
-					&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)) {
-			ptw->ic_attr->preedit_fontset=ptw->font;
-			gdk_ic_set_attr(ptw->ic,ptw->ic_attr,GDK_IC_PREEDIT_FONTSET);
-		}
-#endif
-		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-												0,max,sx,ptw->top.x);
-		set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-												0,ptw->max-1,sy,ptw->top.y);
-		/*  */
-		rc.x=rc.y=0;
-		rc.width=ptw->drawing->allocation.width;
-		rc.height=ptw->drawing->allocation.height;
-		gtk_widget_draw(ptw->drawing,&rc);
-		draw_caret(ptw,NULL);
-	} else {
-		g_free(ft.fontname);
 	}
+	g_free(ft.fontname);
 }
 
 
@@ -670,7 +626,7 @@ void command_replace(gpointer callback_data,guint callback_action,
 		ri.ignorecase=replace_ignorecase;
 		ri.dst=replace_text[0];
 		do {
-			find_operation(ptw,&ptw->cursor,&ptw->select,find_text[0],
+			find_operation(ptw,&ptw->cursor,&select,find_text[0],
 											replace_arrow,replace_ignorecase);
 			if (ptw->select.x<0)
 				break;
