@@ -704,3 +704,84 @@ void jump_operation(TEXTWND *ptw,gint line)
 	}
 	draw_caret(ptw,&cursor);
 }
+
+
+/*	ץѥƥѹ
+	ptw,TXTɥ
+	 ft,ե륿														*/
+void change_property(TEXTWND *ptw,FTYPE *ft)
+{
+	gboolean modify;
+	gint i,fontsize,lbearing,rbearing,width,ascent,descent;
+	gint max,sx,sy;
+	GdkRectangle rc;
+
+	if (ptw->limit!=ft->limit || ptw->tab!=ft->tab
+								|| (ptw->code && ptw->margin!=ft->margin)) {
+		/* ޤ֤ѹֿѹ */
+		delete_list(&ptw->undo);
+		delete_list(&ptw->redo);
+	}
+	modify=ptw->limit!=ft->limit || (ptw->limit
+							&& (ptw->tab!=ft->tab || ptw->margin!=ft->margin));
+	ptw->ft_id=ft->ft_id;
+	ptw->margin=ft->margin;
+	ptw->tab=ft->tab;
+	ptw->code=ft->code;
+	ptw->crlf=ft->crlf;
+	ptw->eof=ft->eof;
+	ptw->limit=ft->limit;
+	ptw->overwrite=ft->overwrite;
+	ptw->space=ft->space;
+	ptw->gline=ft->gline;
+	ptw->mline=ft->mline;
+	ptw->uline=ft->uline;
+	ptw->vline=ft->vline;
+	g_free(ptw->fontname);
+	ptw->fontname=g_strdup(ft->fontname);
+	memcpy(ptw->color,ft->color,sizeof(GdkColor)*12);
+	ptw->select.x=-1;
+	if (modify) {
+		/* ޤ֤ѹޤ֤ͭǥֿѹ */
+		ptw->cursor.x=ptw->cursor.y=ptw->top.x=ptw->top.y=0;
+		modify_margin(ptw);
+	}
+	/* ե */
+	gdk_font_unref(ptw->font);
+	ptw->font=gdk_fontset_load(ptw->fontname);
+	ptw->fontascent=ptw->fontsize=0;
+	for (i=0x20;i<=0x7e;i++) {
+		gdk_text_extents(ptw->font,(gchar *)&i,1,
+								&lbearing,&rbearing,&width,&ascent,&descent);
+		if (ptw->fontascent<ascent)
+			ptw->fontascent=ascent;
+		fontsize=(gdk_char_height(ptw->font,i)+1)/2;
+		if (ptw->fontsize<fontsize)
+			ptw->fontsize=fontsize;
+	}
+	/* С */
+	sx=MAX(ptw->drawing->allocation.width/ptw->fontsize,1);
+	sy=MAX(ptw->drawing->allocation.height/(ptw->fontsize*2),1);
+	if (ptw->top.y>ptw->max-sy)
+		ptw->top.y=MAX(ptw->max-sy,0);
+	max=get_width_max(ptw);
+	if (ptw->top.x>max-sx+1)
+		ptw->top.x=MAX(max-sx+1,0);
+#ifdef USE_XIM
+	if (gdk_im_ready() && ptw->ic!=NULL
+					&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)) {
+		ptw->ic_attr->preedit_fontset=ptw->font;
+		gdk_ic_set_attr(ptw->ic,ptw->ic_attr,GDK_IC_PREEDIT_FONTSET);
+	}
+#endif
+	set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
+												0,max,sx,ptw->top.x);
+	set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
+												0,ptw->max-1,sy,ptw->top.y);
+	/*  */
+	rc.x=rc.y=0;
+	rc.width=ptw->drawing->allocation.width;
+	rc.height=ptw->drawing->allocation.height;
+	gtk_widget_draw(ptw->drawing,&rc);
+	draw_caret(ptw,NULL);
+}
