@@ -97,4 +97,10 @@ void tab_operation(TEXTWND *ptw);
 void jump_operation(TEXTWND *ptw,gint line);
 
 
+/*	ץѥƥѹ
+	ptw,TXTɥ
+	 ft,ե륿														*/
+void change_property(TEXTWND *ptw,FTYPE *ft);
+
+
 #endif
