@@ -34,7 +34,6 @@ static GtkWidget *dialog,*button0,*entry;
 static void jump_dialog_clicked(GtkWidget *widget,JMPDLG *jmp)
 {
 	strval(&jmp->cursor,gtk_entry_get_text(GTK_ENTRY(widget)),10,FALSE);
-	jmp->cursor--;
 	gtk_widget_destroy(dialog);
 	jump_clicked_ok=TRUE;
 }
@@ -46,7 +45,7 @@ static void jump_dialog_activate(GtkWidget *widget,JMPDLG *jmp)
 	gint value;
 
 	strval(&value,gtk_entry_get_text(GTK_ENTRY(widget)),10,FALSE);
-	if (1<=value && value<=jmp->max+1)
+	if (1<=value && value<=jmp->max)
 		jump_dialog_clicked(widget,jmp);
 }
 
@@ -57,7 +56,7 @@ static void jump_dialog_changed(GtkWidget *widget,JMPDLG *jmp)
 	gint value;
 
 	strval(&value,gtk_entry_get_text(GTK_ENTRY(widget)),10,FALSE);
-	gtk_widget_set_sensitive(button0,1<=value && value<=jmp->max+1);
+	gtk_widget_set_sensitive(button0,1<=value && value<=jmp->max);
 }
 
 
@@ -92,7 +91,7 @@ gboolean jump_dialog(JMPDLG *jmp)
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* ȥ꡼ */
 	entry=gtk_entry_new();
-	text=valstr(jmp->cursor+1,10,0,FALSE);
+	text=valstr(jmp->cursor,10,0,FALSE);
 	gtk_entry_set_text(GTK_ENTRY(entry),text);
 	g_free(text);
 	gtk_signal_connect(GTK_OBJECT(entry),"activate",jump_dialog_activate,jmp);
