@@ -28,12 +28,13 @@
 ******************************************************************************/
 static gboolean property_clicked_ok,color_list[12];
 static gchar *fontname;
+static gint ft_id;
 static GdkColor gdk_color[12];
 static GtkWidget *dialog;
 static GtkWidget *button0,*button3;
 static GtkWidget *check0,*check1,*check2,*check3,*check4;
-static GtkWidget *check5,*check6,*check7,*check8,*check9;
-static GtkWidget *clist,*entry0,*entry1,*spin0,*spin1;
+static GtkWidget *check5,*check6,*check7,*check8,*check9,*check10;
+static GtkWidget *clist,*entry0,*entry1,*label,*spin0,*spin1;
 static gchar *color_name[12]={N_("ʸ"),N_("ط"),N_("ȥ륳"),
 		N_("ѥڡ"),N_("ԥ"),N_("ֲ"),
 		N_("ޡ"),N_("å"),N_("򤵤줿ʸ"),
@@ -183,31 +184,41 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
 	gint pos;
 
 	if (ftype_dialog(&pos)) {
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),
-															ftype[pos].gline);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),
-															ftype[pos].space);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),
-															ftype[pos].crlf);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check3),
-															ftype[pos].mline);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check4),
-															ftype[pos].limit);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check5),
-															ftype[pos].code);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check6),
-															ftype[pos].uline);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check7),
-															ftype[pos].vline);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check8),ftype[pos].eof);
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check9),
+		if (pos>=0) {
+			ft_id=ftype[pos].ft_id;
+			gtk_label_set_text(GTK_LABEL(label),ftype[pos].text);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),
+														ftype[pos].gline);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),
+														ftype[pos].space);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),
+														ftype[pos].crlf);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check3),
+														ftype[pos].mline);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check4),
+														ftype[pos].limit);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check5),
+														ftype[pos].code);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check6),
+														ftype[pos].uline);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check7),
+														ftype[pos].vline);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check8),
+														ftype[pos].eof);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check9),
 														ftype[pos].overwrite);
-		gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),ftype[pos].margin);
-		gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),ftype[pos].tab);
-		memcpy(gdk_color,ftype[pos].color,sizeof(GdkColor)*12);
-		g_free(fontname);
-		fontname=g_strdup(ftype[pos].fontname);
-		gtk_widget_set_sensitive(button3,TRUE);
+			gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),
+														ftype[pos].margin);
+			gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),ftype[pos].tab);
+			memcpy(gdk_color,ftype[pos].color,sizeof(GdkColor)*12);
+			g_free(fontname);
+			fontname=g_strdup(ftype[pos].fontname);
+			gtk_widget_set_sensitive(button3,TRUE);
+		} else {
+			ft_id=-1;
+			gtk_label_set_text(GTK_LABEL(label),_("ե륿פʤ"));
+			property_dialog_ok_sensitive(NULL,NULL);
+		}
 	}
 }
 
@@ -215,6 +226,7 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
 /* OKܥ󤬲줿 */
 static void property_dialog_clicked_ok(GtkWidget *widget,FTYPE *ft)
 {
+	ft->ft_id=ft_id;
 	if (entry0!=NULL) {
 		g_free(ft->text);
 		ft->text=g_strdup(gtk_entry_get_text(GTK_ENTRY(entry0)));
@@ -235,6 +247,8 @@ static void property_dialog_clicked_ok(GtkWidget *widget,FTYPE *ft)
 	ft->vline=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check7));
 	ft->eof=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check8));
 	ft->overwrite=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check9));
+	if (check10!=NULL)
+		ft->associate=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check10));
 	memcpy(ft->color,gdk_color,sizeof(GdkColor)*12);
 	g_free(ft->fontname);
 	ft->fontname=fontname;
@@ -341,7 +355,17 @@ gboolean property_dialog(FTYPE *ft)
 											property_dialog_ok_sensitive,NULL);
 	gtk_signal_connect(GTK_OBJECT(check9),"toggled",
 											property_dialog_ok_sensitive,NULL);
-	/* ȥ꡼ */
+	if (ft->text!=NULL && ft->ext!=NULL) {
+		check10=gtk_check_button_new_with_label(
+											_("ե륿פϢŤ"));
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check10),ft->associate);
+		gtk_signal_connect(GTK_OBJECT(check10),"toggled",
+											property_dialog_ok_sensitive,NULL);
+	} else {
+		check10=NULL;
+	}
+	/* ȥ꡼/٥ */
+	label=NULL;
 	if (ft->text!=NULL && ft->ext!=NULL) {
 		entry0=gtk_entry_new_with_max_length(256);
 		entry1=gtk_entry_new_with_max_length(256);
@@ -355,8 +379,15 @@ gboolean property_dialog(FTYPE *ft)
 												property_dialog_clicked_ok,ft);
 		gtk_signal_connect(GTK_OBJECT(entry1),"activate",
 												property_dialog_clicked_ok,ft);
-
 	} else {
+		for (i=0;i<ftnum;i++)
+			if (ft->ft_id==ftype[i].ft_id) {
+				label=gtk_label_new(ftype[i].text);
+				break;
+			}
+		if (label==NULL)
+			label=gtk_label_new(_("ե륿פʤ"));
+		gtk_misc_set_alignment(GTK_MISC(label),0,0.5);
 		entry0=entry1=NULL;
 	}
 	/* ꥹȥܥå */
@@ -401,21 +432,20 @@ gboolean property_dialog(FTYPE *ft)
 											property_dialog_ok_sensitive,NULL);
 
 	/* ե졼ȥܥå */
+	tbox=gtk_hbox_new(FALSE,0);
 	if (entry0!=NULL && entry1!=NULL) {
-		tbox=gtk_hbox_new(FALSE,0);
 		hbox=gtk_hbox_new(FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),
 									gtk_label_new(_("ʸ")),FALSE,FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),entry0,TRUE,TRUE,0);
 		gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,8);
-
 		hbox=gtk_hbox_new(FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),
 									gtk_label_new(_("ĥ")),FALSE,FALSE,0);
 		gtk_box_pack_start(GTK_BOX(hbox),entry1,TRUE,TRUE,0);
 		gtk_box_pack_start(GTK_BOX(tbox),hbox,TRUE,TRUE,8);
 	} else {
-		tbox=NULL;
+		gtk_box_pack_start(GTK_BOX(tbox),label,TRUE,TRUE,8);
 	}
 
 	frame0=gtk_frame_new(_("ɽ"));
@@ -475,13 +505,14 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_box_pack_start(GTK_BOX(hbox),frame4,TRUE,TRUE,8);
 
 	vbox=gtk_vbox_new(FALSE,0);
-	if (tbox!=NULL)
-		gtk_box_pack_start(GTK_BOX(vbox),tbox,FALSE,FALSE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),tbox,FALSE,FALSE,8);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,8);
 	hbox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),button1,FALSE,FALSE,8);
 	if (button2!=NULL)
 		gtk_box_pack_start(GTK_BOX(hbox),button2,FALSE,FALSE,8);
+	if (check10!=NULL)
+		gtk_box_pack_start(GTK_BOX(hbox),check10,FALSE,FALSE,8);
 	gtk_box_pack_end(GTK_BOX(hbox),button4,FALSE,FALSE,8);
 	gtk_box_pack_end(GTK_BOX(hbox),button3,FALSE,FALSE,8);
 	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
@@ -493,6 +524,7 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_widget_set_sensitive(button3,FALSE);
 	gtk_widget_grab_focus(button4);
 
+	ft_id=ft->ft_id;
 	memcpy(gdk_color,ft->color,sizeof(GdkColor)*12);
 	fontname=g_strdup(ft->fontname);
 	property_clicked_ok=FALSE;
