@@ -125,6 +125,8 @@ gint replace_dialog(REPLACE *rp)
 	if (find_num>0) {
 		gtk_combo_set_popdown_strings(GTK_COMBO(combo0),glist);
 		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo0)->entry),find_text[0]);
+		gtk_editable_select_region(GTK_EDITABLE(GTK_COMBO(combo0)->entry),
+																		0,-1);
 	}
 	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo0)->entry),"activate",
 												replace_dialog_activate,rp);
