@@ -19,7 +19,7 @@
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
 #include "edit.h"
-#include "fileop.h"
+#include "file.h"
 #include "general.h"
 #include "other.h"
 #include "signal.h"
@@ -691,7 +691,7 @@ gboolean signal_motion_notify(GtkWidget *widget,
 		x=event->x;
 		y=event->y;
 		state=event->state;
-    }
+	}
 	if ((state&GDK_BUTTON1_MASK)!=0
 			&& signal_motion_notify_draw(ptw,x,y,state) && ptw->timer_id==0)
 		/* Ϥƥ뤷Ȥ */
@@ -728,19 +728,26 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 	case GDK_period:
 	case GDK_less:
 	case GDK_greater:
+	case GDK_H:
+	case GDK_J:
+	case GDK_K:
+	case GDK_L:
+	case GDK_h:
+	case GDK_j:
+	case GDK_k:
+	case GDK_l:
 		{
 			gint sx,sy,width;
-			gboolean ctrl;
+			gboolean alt,ctrl;
 			GdkPoint cursor,top,select;
 
 			cursor=ptw->cursor;
 			top=ptw->top;
 			sx=MAX(ptw->drawing->allocation.width/ptw->fontsize,1);
 			sy=MAX(ptw->drawing->allocation.height/(ptw->fontsize*2),1);
+			alt=(event->state&(GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
+											|GDK_MOD4_MASK|GDK_MOD5_MASK))!=0;
 			ctrl=(event->state&GDK_CONTROL_MASK)!=0;
-			if (!ctrl && (event->keyval==GDK_comma || event->keyval==GDK_period
-					|| event->keyval==GDK_less || event->keyval==GDK_greater))
-				goto loop;
 			switch (event->keyval) {
 			case GDK_Home:
 				ptw->cursor.x=0;
@@ -751,6 +758,10 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				ptw->cursor.x=get_width(&ptw->start,&ptw->off,
 						ctrl?ptw->cursor.y=ptw->max-1:ptw->cursor.y,ptw->tab);
 				break;
+			case GDK_H:
+			case GDK_h:
+				if (!alt)
+					goto loop;
 			case GDK_Left:
 				ptw->cursor.x=get_align_pos(&ptw->start,&ptw->off,
 								ptw->cursor.x,ptw->cursor.y,ptw->tab,FALSE);
@@ -766,6 +777,10 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 													ptw->cursor.y,ptw->tab);
 				}
 				break;
+			case GDK_L:
+			case GDK_l:
+				if (!alt)
+					goto loop;
 			case GDK_Right:
 				width=get_width(&ptw->start,&ptw->off,ptw->cursor.y,ptw->tab);
 				if (ptw->cursor.x<width) {
@@ -781,6 +796,8 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				break;
 			case GDK_comma:
 			case GDK_less:
+				if (!ctrl)
+					goto loop;
 				ptw->cursor.x=get_align_pos(&ptw->start,&ptw->off,
 								ptw->cursor.x,ptw->cursor.y,ptw->tab,FALSE);
 				if (ptw->cursor.x>0) {
@@ -795,6 +812,8 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				break;
 			case GDK_period:
 			case GDK_greater:
+				if (!ctrl)
+					goto loop;
 				width=get_width(&ptw->start,&ptw->off,ptw->cursor.y,ptw->tab);
 				if (ptw->cursor.x<width) {
 					ptw->cursor.x=get_move_pos(&ptw->start,&ptw->off,
@@ -805,6 +824,10 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 					ptw->cursor.y++;
 				}
 				break;
+			case GDK_K:
+			case GDK_k:
+				if (!alt)
+					goto loop;
 			case GDK_Up:
 				if (!ctrl) {
 					ptw->cursor.y--;
@@ -814,6 +837,10 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 						ptw->cursor.y--;
 				}
 				break;
+			case GDK_J:
+			case GDK_j:
+				if (!alt)
+					goto loop;
 			case GDK_Down:
 				if (!ctrl) {
 					ptw->cursor.y++;
@@ -1005,6 +1032,43 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 		draw_caret(ptw,NULL);
 		result=TRUE;
 		break;
+	case GDK_Y:
+	case GDK_y:
+		{
+			DOING *d;
+			GdkPoint select;
+
+			if ((event->state&GDK_CONTROL_MASK)==0)
+				goto loop;
+			select=ptw->select;
+			if (ptw->select.x<0) {
+				if (ptw->max-1<=ptw->cursor.y) {
+					ptw->cursor.x=0;
+					ptw->select.x=get_width(&ptw->start,&ptw->off,
+													ptw->cursor.y,ptw->tab);
+					if (ptw->select.x<=0) {
+						if (ptw->cursor.y<=0) {
+							ptw->select.x=-1;
+						return 0;
+						}
+						ptw->select.y=ptw->cursor.y-1;
+					} else {
+						ptw->select.y=ptw->cursor.y;
+					}
+				} else {
+					ptw->cursor.x=ptw->select.x=0;
+					ptw->select.y=ptw->cursor.y+1;
+				}
+			}
+			d=edit_operation(ptw,NULL,0,FALSE,FALSE);
+			d->next=ptw->undo;
+			ptw->undo=d;
+			if (delete_list(&ptw->redo)>0 || d->next==NULL || select.x>=0)
+				set_menu_bar(ptw);
+			ptw->edit=TRUE;
+		}
+		result=TRUE;
+		break;
 	default:
 		loop:
 		if (event->string!=NULL
@@ -1182,7 +1246,7 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 			str=clipboard_text;
 			length=strlen(clipboard_text);
 		}
-    }
+	}
 	if (str!=NULL) {
 		if (info==TARGET_STRING) {
 			gtk_selection_data_set(data,GDK_SELECTION_TYPE_STRING,
@@ -1205,7 +1269,7 @@ void signal_selection_get(GtkWidget *widget,GtkSelectionData *data,
 
 
 void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
-	                                            guint time,gpointer user_data)
+												guint time,gpointer user_data)
 {
 	gchar *text=NULL,*str,**list;
 	gint i,count;
