@@ -22,7 +22,7 @@
 #include "tmaid.h"
 #include "command.h"
 #include "conf.h"
-#include "fileop.h"
+#include "file.h"
 #include "find.h"
 #include "format.h"
 #include "general.h"
@@ -40,9 +40,10 @@ gboolean has_selection=FALSE;		/* TRUE:ͭ,FALSE:ʤ */
 gboolean newfile=FALSE;				/* TRUE:ե,FALSE:ʤ */
 gchar *hisfile[10];					/* ե */
 gchar *clipboard_text=NULL;			/* åץܡɤΥƥ */
+gint def_width,def_height;			/* ǥեȤΥɥΥ */
 gint ftnum=0;						/* ե륿פο */
 gint history=4;						/* ե */
-gint def_width,def_height;			/* ǥեȤΥɥΥ */
+gint tcount=0;						/* ե륿פΥ */
 guint timer_id=0;					/* ID */
 FTYPE *ftype=NULL;					/* ե륿 */
 GdkAtom clipboard_atom;				/* åץܡ */
@@ -53,7 +54,30 @@ GtkItemFactory *item_factory_menu;	/* ˥塼 */
 GtkItemFactory *item_factory_popup;	/* ݥåץå */
 
 
-GtkItemFactoryEntry menu_items[]={
+/******************************************************************************
+*                                                                             *
+* ᥤؿ                                                                  *
+*                                                                             *
+******************************************************************************/
+int main(int argc,char *argv[])
+{
+	gboolean *arg_files;
+	gchar *arg,*endptr,*str,*section=NULL,*key=NULL;
+	gint i,j,k,l,m,opt,leng;
+	gint init_line=0;					/* ΥåȰ */
+	PROFILE *profile;
+	TEXTWND *ptw;
+	GdkBitmap *mask;
+	GdkPixmap *pixmap;
+	GtkAccelGroup *accel_group;
+	GtkWidget *menubar,*toolbar,*sub_menu,*menu_item,*vbox;
+	GdkColor color[12]={{0,0x0000,0x0000,0x0000},{0,0xffff,0xffff,0xffff},
+						{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
+						{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
+						{0,0x8000,0x8000,0x8000},{0,0xa000,0xa000,0xa000},
+						{0,0xffff,0xffff,0xffff},{0,0x0000,0x0000,0x8000},
+						{0,0x0000,0x0000,0x0000},{0,0x8000,0x8000,0x8000}};
+	GtkItemFactoryEntry menu_items[]={
 {N_("/ե(_F)"),                               NULL,         NULL,            0,"<Branch>"},
 {N_("/ե(F)/(_N)"),                   "<control>N", command_new,     0,"<Item>"},
 {N_("/ե(F)/(_O)..."),                    "<control>O", command_open,    0,"<Item>"},
@@ -92,40 +116,16 @@ GtkItemFactoryEntry menu_items[]={
 {N_("/ɥ(_W)"),                             NULL,         NULL,            0,"<Branch>"},
 {N_("/إ(_H)"),                                 NULL,         NULL,            0,"<Branch>"},
 {N_("/إ(H)/С(_A)..."),            NULL,         version_dialog,  0,"<Item>"}};
-
-
-/******************************************************************************
-*                                                                             *
-* ᥤؿ                                                                  *
-*                                                                             *
-******************************************************************************/
-int main(int argc,char *argv[])
-{
-	gboolean *arg_files;
-	gchar *arg,*endptr,*str,*section=NULL,*key=NULL;
-	gint i,j,k,opt;
-	gint init_line=0;					/* ΥåȰ */
-	PROFILE *profile;
-	TEXTWND *ptw;
-	GdkBitmap *mask;
-	GdkPixmap *pixmap;
-	GtkAccelGroup *accel_group;
-	GtkWidget *menubar,*toolbar,*sub_menu,*menu_item,*vbox;
-	GdkColor color[12]={{0,0x0000,0x0000,0x0000},{0,0xffff,0xffff,0xffff},
-						{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
-						{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
-						{0,0x8000,0x8000,0x8000},{0,0xa000,0xa000,0xa000},
-						{0,0xffff,0xffff,0xffff},{0,0x0000,0x0000,0x8000},
-						{0,0x0000,0x0000,0x0000},{0,0x8000,0x8000,0x8000}};
 	GtkItemFactoryEntry popup_items[]={
-		{N_("/᤹(_U)"),  "<control>Z",command_undo,  0,"<Item>"},
-		{N_("/Sep1"),          NULL,        NULL,          0,"<Separator>"},
-		{N_("/ڤ(_T)"),  "<control>X",command_cut,   0,"<Item>"},
-		{N_("/ԡ(_C)"),    "<control>C",command_copy,  0,"<Item>"},
-		{N_("/Žդ(_P)"),  "<control>V",command_paste, 0,"<Item>"},
-		{N_("/(_L)"),      NULL,        command_delete,0,"<Item>"},
-		{N_("/Sep2"),          NULL,        NULL,          0,"<Separator>"},
-		{N_("/٤(_A)"),"<control>A",command_all,   0,"<Item>"}};
+{N_("/᤹(_U)"),                               "<control>Z", command_undo,    0,"<Item>"},
+{N_("/Sep1"),                                       NULL,         NULL,            0,"<Separator>"},
+{N_("/ڤ(_T)"),                               "<control>X", command_cut,     0,"<Item>"},
+{N_("/ԡ(_C)"),                                 "<control>C", command_copy,    0,"<Item>"},
+{N_("/Žդ(_P)"),                               "<control>V", command_paste,   0,"<Item>"},
+{N_("/(_L)"),                                   NULL,         command_delete,  0,"<Item>"},
+{N_("/Sep2"),                                       NULL,         NULL,            0,"<Separator>"},
+{N_("/٤(_A)"),"<control>A",command_all,   0,"<Item>"}};
+	/* Drag&Drop */
 	GtkTargetEntry drag_types[1]={{"text/uri-list",0,0}};
 	/* Text maid󶡲ǽʥ쥯 */
 	GtkTargetEntry targets[]={
@@ -233,6 +233,7 @@ int main(int argc,char *argv[])
 			ftype=g_malloc(ftnum*sizeof(FTYPE));
 		for (i=0;i<ftnum;i++) {
 			section=g_strdup_printf("filetype%04d",i);
+			ftype[i].ft_id=tcount++;
 			if ((ftype[i].text
 							=profile_get_string(profile,section,"text"))==NULL)
 				ftype[i].text=g_strdup("UNKNOW");
@@ -247,6 +248,10 @@ int main(int argc,char *argv[])
 								(gpointer)&ftype[i].tab,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 				ftype[i].tab=8;
+			if (!profile_get_value(profile,section,"associate",
+								(gpointer)&ftype[i].associate,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+				ftype[i].associate=TRUE;
 			if (!profile_get_value(profile,section,"code",
 								(gpointer)&ftype[i].code,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
@@ -306,78 +311,94 @@ int main(int argc,char *argv[])
 	/* ޥɥ饤β */
 	arg_files=g_malloc(argc*sizeof(gboolean));
 	memset(arg_files,0,argc*sizeof(gboolean));
-	for (i=1;i<argc;i++) {
+	i=1;/* i:Υץ,j:iʸ,k:iʹߤarg */
+	while (i<argc) {
 		if ((argv[i])[0]=='-') {/* ץ */
-			if ((argv[i])[1]=='-') {	/* Ĺץ */
-				opt=0;
-				for (j=0;arg_opts[j].name!=NULL;j++)
-					if (g_strncasecmp(argv[i]+2,arg_opts[j].name,
-						MIN(strlen(argv[i])-2,strlen(arg_opts[j].name)))==0) {
-						opt=arg_opts[j].key;
+			j=1;
+			k=i;
+			while ((argv[i])[j]!='\0' && (argv[i])[j]!='=') {
+				if ((argv[i])[1]=='-') {	/* Ĺץ */
+					opt=0;
+					for (l=0;arg_opts[l].name!=NULL;l++) {
+						leng=strlen(arg_opts[l].name);
+						if (g_strncasecmp(argv[i]+2,arg_opts[l].name,leng)==0
+											&& ((argv[i])[leng+2]=='\0'
+												|| (argv[i])[leng+2]=='=')) {
+							opt=arg_opts[l].key;
+							j=leng+2;
+							break;
+						}
+					}
+				} else {					/* ûץ */
+					opt=tolower((argv[i])[j++]);
+				}
+				arg=NULL;
+				for (l=0;arg_opts[l].name!=NULL;l++)
+					if (arg_opts[l].key==opt && arg_opts[l].arg!=NULL) {
+						if (i==k) {
+							for (m=2;(argv[i])[m]!='\0' && (argv[i])[m]!='=';
+																		m++);
+							arg=(argv[i])[m]=='\0'?argv[++k]:argv[i]+m+1;
+							k++;
+						} else {
+							arg=argv[k++];
+						}
+						if (arg==NULL || *arg=='\0')
+							opt=0;
 						break;
 					}
-			} else {					/* ûץ */
-				opt=tolower((argv[i])[1]);
-			}
-			arg=NULL;
-			for (j=0;arg_opts[j].name!=NULL;j++)
-				if (arg_opts[j].key==opt && arg_opts[j].arg!=NULL) {
-					for (k=2;(argv[i])[k]!='\0' && (argv[i])[k]!='=';k++);
-					arg=(argv[i])[k]=='\0'?argv[++i]:argv[i]+k+1;
-					if (arg==NULL || *arg=='\0')
-						opt='?';
-					break;
-				}
-			switch (opt) {
-				case 'h':
-					strval(&history,arg,10,TRUE);
-					if (history<0)
-						history=0;
-					else if (history>10)
-						history=10;
-					break;
-				case 'l':
-					strval(&init_line,arg,10,TRUE);
-					break;
-				case 'n':
-					newfile=g_strcasecmp(arg,"OK")==0
+				switch (opt) {
+					case 'h':
+						strval(&history,arg,10,TRUE);
+						if (history<0)
+							history=0;
+						else if (history>10)
+							history=10;
+						break;
+					case 'l':
+						strval(&init_line,arg,10,TRUE);
+						break;
+					case 'n':
+						newfile=g_strcasecmp(arg,"OK")==0
 												|| g_strcasecmp(arg,"TRUE")==0
 												|| g_strcasecmp(arg,"YES")==0;
-					break;
-				case 's':
-					def_height=strtol(arg,&endptr,0);
-					def_width=strtol(++endptr,&endptr,0);
-					break;
-				case 'v':
-					g_print(
+						break;
+					case 's':
+						def_height=strtol(arg,&endptr,0);
+						def_width=strtol(++endptr,&endptr,0);
+						break;
+					case 'v':
+						g_print(
 "Text maid "VERSION"\n"
 "Copyright (C) 1998-2002 Iwamoto,Kazuki\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
-					);
-					g_free(arg_files);
-					return 0;
-				default:
-					g_print(
+						);
+						g_free(arg_files);
+						return 0;
+					default:
+						g_print(
 "Copyright (c) 1998-2002 Iwamoto,Kazuki\n\n"
 "Usage: %s [OPTION...] [FILE...]\n\n",argv[0]);
-					for (i=0;arg_opts[i].name;i++) {
-						if (arg_opts[i].arg!=NULL)
-							str=g_strdup_printf("  -%c, --%s=%s",
+						for (i=0;arg_opts[i].name;i++) {
+							if (arg_opts[i].arg!=NULL)
+								str=g_strdup_printf("  -%c, --%s=%s",
 											arg_opts[i].key,arg_opts[i].name,
 															arg_opts[i].arg);
-						else
-							str=g_strdup_printf("  -%c, --%s",
+							else
+								str=g_strdup_printf("  -%c, --%s",
 											arg_opts[i].key, arg_opts[i].name);
-						g_print("%-26s %s\n",str,arg_opts[i].doc);
-						g_free(str);
-					}
-					g_print("\n");
-					g_free(arg_files);
-					return 0;
+							g_print("%-26s %s\n",str,arg_opts[i].doc);
+							g_free(str);
+						}
+						g_print("\n");
+						g_free(arg_files);
+						return 0;
+				}
 			}
+			i=i<k?k:i+1;
 		} else {/* ե */
-			arg_files[i]=TRUE;
+			arg_files[i++]=TRUE;
 		}
 	}
 
@@ -391,6 +412,7 @@ int main(int argc,char *argv[])
 		ftype[1].ext=g_strdup("*");
 		ftype[0].margin=ftype[1].margin=80;
 		ftype[0].tab=ftype[1].tab=8;
+		ftype[0].associate=ftype[1].associate=TRUE;
 		ftype[0].code=ftype[1].code=FALSE;
 		ftype[0].crlf=ftype[1].crlf=FALSE;
 		ftype[0].eof=ftype[1].eof=FALSE;
@@ -603,6 +625,9 @@ int main(int argc,char *argv[])
 			profile_set_value(profile,section,"tab",
 								(gpointer)&ftype[i].tab,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
+			profile_set_value(profile,section,"associate",
+								(gpointer)&ftype[i].associate,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"code",
 								(gpointer)&ftype[i].code,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
