@@ -34,8 +34,8 @@
 
 
 typedef struct ftype {
-	gchar *text,*ext;			/* ̾,ĥ */
-	gchar *fontname;			/* ե̾ */
+	gint ft_id;					/* ե륿פID */
+	gboolean associate;			/* TRUE:ϢŤ */
 	gboolean create;			/* TRUE:,FALSE:¸ե */
 	gboolean edit;				/* TRUE:ԽѤ,FALSE:̤Խ */
 	gboolean code;				/* TRUE:֤Υɤɽ */
@@ -48,6 +48,8 @@ typedef struct ftype {
 	gboolean mline;				/* TRUE:ޡɽ */
 	gboolean uline;				/* TRUE:ֲɽ */
 	gboolean vline;				/* TRUE:ֽɽ */
+	gchar *text,*ext;			/* ̾,ĥ */
+	gchar *fontname;			/* ե̾ */
 	gint margin;				/* ޡο */
 	gint tab;					/* ֤ο */
 	GdkColor color[12];			/*  */
@@ -80,6 +82,7 @@ typedef struct textwnd {
 	gboolean mline;				/* TRUE:ޡɽ */
 	gboolean uline;				/* TRUE:ֲɽ */
 	gboolean vline;				/* TRUE:ֽɽ */
+	gint ft_id;					/* ե륿פID(-1:̵°) */
 	gint fontsize;				/* եȤβ */
 	gint fontascent;			/* եȤΥȤι⤵ */
 	gint margin;				/* ޡο */
@@ -117,9 +120,10 @@ extern gboolean has_selection;			/* TRUE:ͭ,FALSE:ʤ */
 extern gboolean newfile;				/* TRUE:ե,FALSE:ʤ */
 extern gchar *clipboard_text;			/* åץܡɤΥƥ */
 extern gchar *hisfile[10];				/* ե */
+extern gint def_width,def_height;		/* ǥեȤΥɥΥ */
 extern gint ftnum;						/* ե륿פο */
 extern gint history;					/* ե */
-extern gint def_width,def_height;		/* ǥեȤΥɥΥ */
+extern gint tcount;						/* ե륿פΥ */
 extern guint timer_id;					/* ID */
 extern FTYPE *ftype;					/* ե륿 */
 extern GdkAtom clipboard_atom;			/* åץܡ */
